import os
from zc.async.testing import wait_for_result
from zope.interface.verify import verifyClass, verifyObject
from zope.component import getUtility, createObject
from waeup.kofa.interfaces import IJobManager
from waeup.kofa.students.tests.test_catalog import CatalogTestSetup
from waeup.kofa.students.tests.test_browser import StudentsFullSetup
from waeup.kofa.tests.test_async import FunctionalAsyncTestCase
from waeup.kofa.browser.tests.test_pdf import samples_dir

from waeup.aaue.students.reports.raw_score_report import (
    get_students, get_courses, RawScoreReport, IRawScoreReport)
from waeup.aaue.testing import FunctionalLayer

class RawScoreReportTests(CatalogTestSetup):

    layer = FunctionalLayer

    def setUp(self):
        super(RawScoreReportTests, self).setUp()
        self.course = createObject('waeup.Course')
        self.course.code = 'Course1'
        self.app['faculties']['fac1']['dep1'].courses.addCourse(
            self.course)
        self.app['faculties']['fac1']['dep1'].certificates[
            'CERT1'].addCertCourse(self.course, level=100)

    def test_iface(self):
        # ensure we fullfill interface contracts
        obj = RawScoreReport('fac1', 'dep1', 2010, 100)
        verifyClass(IRawScoreReport, RawScoreReport)
        verifyObject(IRawScoreReport, obj)
        return

    def test_get_courses(self):
        # we can get a list with one course code
        result = get_courses('fac1', 'dep1', 100)
        self.assertEqual(result, [(u'Course1')])
        return

    def test_get_students(self):
        # we can get a table with one student
        course_codes = get_courses('fac1', 'dep1', 100)
        result = get_students('fac1', 'dep1', 2010, 100, course_codes)
        self.assertEqual(result,
            [(u'1234', u'TESTER, Bob', {'Course1': (88, 'A')})])
        return

    def test_create_pdf(self):
        report = RawScoreReport('fac1', 'dep1', 2010, 100)
        result = report.create_pdf()
        self.assertTrue(result.startswith('%PDF-'))
        path = os.path.join(samples_dir(), 'raw_score_report.pdf')
        open(path, 'wb').write(result)
        print "Sample raw_score_report.pdf written to %s" % path
        return
